@@ -1,5 +1,5 @@
 package Statocles::Types;
-our $VERSION = '0.088';
+our $VERSION = '0.089';
 # ABSTRACT: Type constraints and coercions for Statocles
 
 use strict;
@@ -9,10 +9,12 @@ use Type::Library -base, -declare => qw(
     Store Theme Link LinkArray LinkHash LinkTree LinkTreeArray
     DateTimeObj DateStr DateTimeStr
     Person
+    PagePath
 );
 use Type::Utils -all;
 use Types::Standard -types;
 use DateTime::Moonpig;
+use Mojo::Path;
 
 role_type Store, { role => "Statocles::Store" };
 coerce Store, from Str, via { Statocles::Store->new( path => $_ ) };
@@ -82,6 +84,9 @@ coerce DateTimeObj, from DateTimeStr, via {
     );
 };
 
+class_type PagePath, { class => "Mojo::Path" };
+coerce PagePath, from Str, via { Mojo::Path->new( $_ ) };
+
 sub DateTime::Moonpig::tzoffset {
     my ( $self ) = @_;
     warn "The tzoffset shim method will be removed in Statocles version 2.0. See Statocles::Help::Upgrading for instructions to remove this warning.\n";
@@ -109,7 +114,7 @@ Statocles::Types - Type constraints and coercions for Statocles
 
 =head1 VERSION
 
-version 0.088
+version 0.089
 
 =head1 SYNOPSIS
 
@@ -144,6 +149,11 @@ version 0.088
         coerce => DateTimeObj->coercion,
     );
 
+    has path => (
+        isa => PagePath,
+        coerce => PagePath->coercion,
+    );
+
 =head1 DESCRIPTION
 
 This is a L<type library|Type::Tiny::Manual::Library> for common Statocles types.
@@ -191,6 +201,11 @@ This can be coerced from any HashRef of ArrayRef of HashRefs.
 A L<DateTime::Moonpig> object representing a date/time. This can be coerced from a
 C<YYYY-MM-DD> string or a C<YYYY-MM-DD HH:MM:SS> string.
 
+=head2 PagePath
+
+A L<Mojo::Path> object representing the path portion of a URL. It can
+be coerced from a suitable string.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
